Learn R Programming

archeoViz (version 1.4.1)

demo_refits_data: Generates a "refits" data set populated with random values.

Description

A convenient function to generate a data set to be used for the refits.df parameter of the archeoViz function.

Usage

demo_refits_data(n.objects)

Value

A matrix with 2 columns containing random pairs of numerica values (corresponding to the unique identifiers of the objects generated with the demo_objects_data function).

Arguments

n.objects

numerical, number of objects between which refitting relationships must be created.

Author

Sebastien Plutniak <sebastien.plutniak at posteo.net>

Examples

Run this code
	if (FALSE) demo_refits_data(n.objects.df=100)

Run the code above in your browser using DataLab