Learn R Programming

archeoViz (version 1.4.1)

demo_timeline_data: Generates a "timeline" data set populated with random values.

Description

A convenient function to generate a data set to be used for the timeline.df parameter of the archeoViz function.

Usage

demo_timeline_data()

Arguments

Value

A data frame with 3 columns containing random data ("year", "square_x", "square_y").

Author

Sebastien Plutniak <sebastien.plutniak at posteo.net>

Details

Note that there is no correspondance between the data generated with demo_timeline_data and the data generated with demo_objects_data and demo_refits_data.

Examples

Run this code
	if (FALSE) demo_timeline_data()

Run the code above in your browser using DataLab